<?php
/*
Plugin Name: Display graph by chartjs
Plugin URI: https://tarovlog.com/display-graph-by-chartjs/
Description: Chart JS を使ったグラフ描画プラグイン
Version: 1.0.0
Author: tarovlog
Author URI: https://tarovlog.com/
License: GPL2
*/

/*
 * js, css の読み込み
 *************************************/
function add_my_style_and_scripts() {
    wp_enqueue_script('my-chartjs', plugins_url() . '/display-graph-by-chartjs/js/Chart.min.js', null, '2.8.0', false);
    wp_enqueue_script('my-chartjs-plugin', plugins_url() . '/display-graph-by-chartjs/js/chartjs-plugin-labels.js', null, '2.8.0', false);
}
add_action('wp_enqueue_scripts', 'add_my_style_and_scripts');

/*
 * graph用のClass
 *************************************/
class Dgbcshowgraph {

	function __construct($type, $title, $x_data, $y_data, $y_top, $y_label, $height, $bordercolor, $backgroundcolor, $unit)	{
		$this->type = $type;
    $this->title = $title;
    $this->x_data = $this->makelist($x_data);
    $this->y_data = $y_data;
    $this->y_top = $y_top;
    $this->y_label = $y_label;
    $this->height = $height;
    $this->bordercolor = $bordercolor;
    $this->backgroundcolor = $this->makelist($backgroundcolor);
    $this->shuffled = str_shuffle('abcdef');
    $this->unit = $unit;
	}

  function checker() {
    echo '<pre>';
    echo $this->type;
    echo $this->title;
    echo $this->x_data;
    echo $this->y_data;
    echo $this->y_top;
    echo $this->y_label;
    echo $this->height;
    echo $this->bordercolor;
    echo $this->backgroundcolor;
    echo $this->shuffled;
    echo $this->unit;
    echo '</pre>';
  }

  function head() {
    $html = '';
    $html .= "<div style='height: {$this->height}px'>";
    $html .= "<canvas id='{$this->shuffled}'></canvas>";
    $html .= "</div>";
    $html .= "<a href='https://tarovlog.com/display-graph-by-chartjs/' style=' font-size: 12px; font-style: italic;'>Made by たろブログ</a>";
    return $html;
  }

  function makelist($data) {
    $arr = explode(',', str_replace(' ', '', $data));
    $output = '\''.join("','", $arr).'\'';
    return $output;
  }

	function oresen_graph() {
    $html = '';
    $html .= <<<EOT
    <script>
    var ctx = document.getElementById('{$this->shuffled}').getContext('2d');
    var myLineChart = new Chart(ctx, {
    type: '{$this->type}',
    data: {
      labels: [{$this->x_data}],
      datasets: [
        {
          label: '{$this->y_label}',
          data: [{$this->y_data}],
          borderColor: "{$this->bordercolor}",
          backgroundColor: "rgba(0,0,0,0)"
        }
      ],
    },
    options: {
      responsive: true,
      maintainAspectRatio: false,
      title: {
        display: true,
        text: '{$this->title}'
      },
      scales: {
        yAxes: [{
          ticks: {
            suggestedMax: {$this->y_top},
            suggestedMin: 0,
          }
        }]
      },
    }
  });
    </script>
EOT;
  return $html;
	}

  function en_graph() {
    $html = '';
    $html .= <<<EOT
    <script>
    var ctx = document.getElementById('{$this->shuffled}').getContext('2d');
    var myLineChart = new Chart(ctx, {
    type: '{$this->type}',
    data: {
      labels: [{$this->x_data}],
      datasets: [{
        backgroundColor: [{$this->backgroundcolor}],
        data: [{$this->y_data}]
      }],
    },
    options: {
      responsive: true,
      maintainAspectRatio: false,
      title: {
        display: true,
        text: '{$this->title}'
      },
      plugins: {
        labels: {

          render: function (args) {
            return args.label +'\\n'+ args.value + '{$this->unit}';
          },
          position: 'default',
          fontSize: 12,
          fontColor: '#333',
          overlap: false,
        }
      }
    }
  });
    </script>
EOT;
  return $html;
	}
}

/*
 * plot single data shortcode
 *************************************/
function dgbc_display_graph_single($atts) {
    wp_enqueue_script('my-chartjs');
    wp_enqueue_script('my-chartjs-plugin');

    // set parameter
    $type = empty($atts['type']) ? 'line' : $atts['type'];
    $title = empty($atts['title']) ? '' : $atts['title'];
    $x_data = empty($atts['x_data']) ? "1月, 2月, 3月, 4月, 5月" : $atts['x_data'];
    $y_data = empty($atts['y_data']) ? "10, 30, 60, 150, 280" : $atts['y_data'];
    $y_top = empty($atts['y_top']) ? '100' : $atts['y_top'];
    $y_label = empty($atts['y_label']) ? '' : $atts['y_label'];
    $height = empty($atts['height']) ? '300' : $atts['height'];
    $bordercolor = empty($atts['bordercolor']) ? '#778899' : $atts['bordercolor'];
    $backgroundcolor = empty($atts['backgroundcolor']) ? 'rgba(0,0,0,0)' : $atts['backgroundcolor'];
    $unit = empty($atts['unit']) ? '' : $atts['unit'];

    // chart type
    if (empty($type)) {
        return 'グラフの種類を指定してください。';
    }
    // input (x, y) data
    if (empty($x_data) || empty($y_data)) {
        return 'x_dataまたはy_dataデータを入力してください。';
    }

    // $html = '<script src="https://cdnjs.cloudflare.com/ajax/libs/Chart.js/2.8.0/Chart.min.js"></script>';
    // $html .= '<script src="https://cdn.jsdelivr.net/gh/emn178/chartjs-plugin-labels/src/chartjs-plugin-labels.js"></script>';
    // $graph->checker();
    $graph = new Dgbcshowgraph($type, $title, $x_data, $y_data, $y_top, $y_label, $height, $bordercolor, $backgroundcolor, $unit);
    $html .= $graph->head();
    if ($type == 'line') {
      $html .= $graph->oresen_graph();
    } else if ($type == 'pie') {
      $html .= $graph->en_graph();
    }

    return $html;
}
add_shortcode( 'display_graph_single', 'dgbc_display_graph_single');


